@@ -8,9 +8,10 @@ use Path::Class::File;
 use YAML ();
 use Term::ANSIColor ();
 use Path::Class qw( file dir );
+use File::ShareDir ();
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.96'; # VERSION
+our $VERSION = '1.97'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -266,6 +267,14 @@ sub configure
   }
 }
 
+
+sub dist_dir
+{
+  Path::Class::Dir->new(
+    File::ShareDir::dist_dir('Dist-Zilla-PluginBundle-Author-Plicease')
+  );
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -282,7 +291,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.96
+version 1.97
 
 =head1 SYNOPSIS
 
@@ -494,6 +503,14 @@ Specify an alternative to OurPkgVersion for updating the versions in .pm files.
 
 Specify a minimum Perl version.  If not specified it will be detected.
 
+=head1 METHODS
+
+=head2 dist_dir
+
+ my $dir = Dist::Zilla::PluginBundle::Author::Plicease->dist_dir;
+
+Returns this distributions share directory.
+
 =head1 SEE ALSO
 
 =over 4
